Package: clusterSeq
Type: Package
Title: Clustering of high-throughput sequencing data by identifying
        co-expression patterns
Version: 1.36.0
Depends: R (>= 3.0.0), methods, BiocParallel, baySeq, graphics, stats,
        utils
Imports: BiocGenerics
Suggests: BiocStyle
Date: 2016-01-19
Authors@R: c(person("Thomas J.", "Hardcastle", role = "aut"),
  person("Irene", "Papatheodorou", role = "aut"),
  person("Samuel", "Granjeaud", role = "cre", email = "samuel.granjeaud@inserm.fr", comment=c(ORCID="0000-0001-9245-1535")))
Description: Identification of clusters of co-expressed genes based on
        their expression across multiple (replicated) biological
        samples.
License: GPL-3
LazyLoad: yes
biocViews: Sequencing, DifferentialExpression, MultipleComparison,
        Clustering, GeneExpression
URL: https://github.com/samgg/clusterSeq
BugReports: https://github.com/samgg/clusterSeq/issues
Repository: https://bioc-release.r-universe.dev
Date/Publication: 2026-04-28 12:44:49 UTC
RemoteUrl: https://github.com/bioc/clusterSeq
RemoteRef: RELEASE_3_23
RemoteSha: e53b3fc46a6e2a40526b535daa3e7e6b60c388ca
NeedsCompilation: no
Packaged: 2026-04-29 20:40:22 UTC; root
Author: Thomas J. Hardcastle [aut],
  Irene Papatheodorou [aut],
  Samuel Granjeaud [cre] (ORCID: <https://orcid.org/0000-0001-9245-1535>)
Maintainer: Samuel Granjeaud <samuel.granjeaud@inserm.fr>
Built: R 4.6.0; ; 2026-04-29 20:48:29 UTC; unix
